EpubChapter class

Constructors

EpubChapter({String? title, String? contentFileName, String? anchor, String? htmlContent, List<EpubChapter> subChapters = const <EpubChapter>[]})
const

Properties

anchor String?
final
contentFileName String?
final
hashCode int
The hash code for this object.
no setteroverride
htmlContent String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subChapters List<EpubChapter>
final
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant EpubChapter other) bool
The equality operator.
override