EpubGuide class

Constructors

EpubGuide({List<EpubGuideReference> items = const <EpubGuideReference>[]})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<EpubGuideReference>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant EpubGuide other) bool
The equality operator.
override