EpubNavigation class
Constructors
-
const
Properties
-
docAuthors
→ List<
EpubNavigationDocAuthor> -
final
- docTitle → EpubNavigationDocTitle?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- head → EpubNavigationHead?
-
final
-
final
-
final
- pageList → EpubNavigationPageList?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
covariant EpubNavigation other) → bool -
The equality operator.
override